lm_FTPK <- function()
{
#
#  Set output file name.
#
    sink("OUTPUT/MJJRO.FTPK.FinalMLR.out")
#
#  Read input files.
#
#  Calibration data from stations:

    CalibData  <- read.table("INPUT/VARS.STNS.FTPK.1992-2011.CALIB.txt", header=TRUE)
    ValidData  <- read.table("INPUT/VARS.STNS.FTPK.1992-2011.VALID.txt", header=TRUE)
    CCSM3Data <- read.table("INPUT/CCSM3.FTPK.VARS.1992-2099.txt", header=TRUE)
    CCSM4Data <- read.table("INPUT/CCSM4.FTPK.VARS.1992-2099.txt", header=TRUE)
#
#
#  Transform to log of runoff.
#
    CalibData$LOGMJJRO = log10(CalibData$MJJRO)
#
#  Linear regression for May-June runoff in a given year.
#
    yy = lm(LOGMJJRO ~ PEAKSWE + PRECAMJPLN + EVAPJASFTH + PRECONDPLN + EVAPONDPLN, data=CalibData)
    print(summary(yy))
#
    print(" ")
    print("*************************************************************************")
    print("* Ouput of coefficients from stepwise regression.                       *")
    print("*************************************************************************")
    print(" ")

    print(coefficients(yy))
#
#  Write out observed verus modeled.
#
    yy_fit = fitted(yy)
    write.table(cbind(CalibData$YEAR, CalibData$MJJRO, 10^yy_fit), file="OUTPUT/MJJRO.FTPK.CALIB.1992-2011.out")
#
#  Predict runoff using validation dataset.
#
    RUNOFF_validation = predict(yy, newdata=ValidData, interval="prediction")
    write.table(cbind(ValidData$YEAR, 10^RUNOFF_validation), file="OUTPUT/MJJRO.FTPK.VALID.1992-2011.out")
#
#  Predict SWE using CCSM output temperature and precipitation.
#
    RUNOFF_projected = predict(yy, newdata=CCSM3Data, interval="prediction")
    write.table(cbind(CCSM3Data$YEAR, 10^RUNOFF_projected), file="OUTPUT/MJJRO.CCSM3.FTPK.out")
#
    RUNOFF_projected = predict(yy, newdata=CCSM4Data, interval="prediction")
    write.table(cbind(CCSM4Data$YEAR, 10^RUNOFF_projected), file="OUTPUT/MJJRO.CCSM4.FTPK.out")
#
#  Return output to the terminal.
#
    sink()
}
